from thotnr_ml_client.ConfigurationManager import ConfigurationManager
from thotnr_ml_client.WebClient import WebClient
from thotnr_ml_client.GraphQlWebClient import GraphQlWebClient
from thotnr_ml_client.MLModel import MLModel



from thotnr_ml_client.GraphQlWebClient import GraphQlWebClient
from thotnr_ml_client.ConfigurationManager import ConfigurationManager


class MLModel:
    def __init__(self):
        self._config_manager = ConfigurationManager()
        self._graphql_web_client = GraphQlWebClient(self._config_manager)
        self._graphql_web_client.refresh_token()

    def register_model(self, s3_path, model_metadata, is_active):
        is_active_string = "true" if is_active else "false"
        ml_code = self._config_manager.get_ml_code()
        group_id = self._config_manager.get_current_group_id()

        input_string = (
            f's3Path:"{s3_path}",'
            f'groupId:"{group_id}",'
            f'modelMetadata:"{model_metadata}",'
            f'isActive:{is_active_string},'
            f'mlCode:"{ml_code}"'
        )

        agi_id = self._config_manager.get_current_agi_id()
        query = (
            f'mutation {{ createMlModel{agi_id}_api (input: {{MlModel{agi_id}_api: {{ {input_string} }} }}) {{ '
            f'MlModel{agi_id}_api {{ s3Path, groupId, modelMetadata, isActive, mlCode, created_on }} }} }}'
        )
        return self._graphql_web_client.query(query, "mutation")

    def get_current_active_model(self):
        ml_code = self._config_manager.get_ml_code()
        group_id = self._config_manager.get_current_group_id()
        agi_id = self._config_manager.get_current_agi_id()

        query = f"""
                query MyQuery {{
                    MlModel{agi_id}_api (
                        filter: {{
                            groupId: {{equalTo: "{group_id}"}},
                            and: {{
                                mlCode: {{equalTo: "{ml_code}"}},
                                and: {{isActive: {{equalTo: true}}}}
                            }}
                        }},
                        first: 1
                    ) {{
                        nodes {{
                            s3Path, groupId, modelMetadata, isActive, mlCode, created_on
                        }}
                    }}
                }}
            """

        return self._graphql_web_client.query(query, "query")


if __name__ == '__main__':
    ml_model = MLModel()
    print(ml_model.get_current_active_model())
    # ml_model.register_model(s3_path="abc", model_metadata="cde", is_active=False)



import os
import base64
import json


class ConfigurationManager:
    AUTHORIZATION = "Authorization"
    QUERY_PARAM_FOR_APP_INSTANCE_ID = "appInstanceId"
    QUERY_PARAM_BITEMPORAL_PROPS = "biTemporalProps"
    QUERY_PARAM_TIME_LABEL_PROP = "timeLabel"
    QUERY_PARAM_CURRENTLY_EXECUTING_JOB_ID = "currentJobId"
    ML_CODE_PROP = "mlCode"
    GROUP_ID = "groupId"
    AGI_ID = "agiId"
    EP_ID = "epId"

    def __init__(self):
        self._auth_token = ""
        self._json_config = json.loads(os.environ["CONFIG"])
        token_obj = json.loads(base64.b64decode(self._json_config["TOKEN"]).decode("utf-8"))
        self._host_name = token_obj["hostName"]
        self._session_code = self._json_config["sessionCode"]
        self._agiId = str(self._json_config[
                              self.AGI_ID]) if self.AGI_ID in self._json_config else None
        self._token = token_obj["refreshToken"]
        self._bitemporal_props = (
            '"' + str(self._json_config[
                          self.QUERY_PARAM_BITEMPORAL_PROPS]) + '"' if self.QUERY_PARAM_BITEMPORAL_PROPS in self._json_config else None)
        self._time_label = self._json_config[
            self.QUERY_PARAM_TIME_LABEL_PROP] if self.QUERY_PARAM_TIME_LABEL_PROP in self._json_config else None
        self._app_instance_id = str(self._json_config[
                                        self.QUERY_PARAM_FOR_APP_INSTANCE_ID]) if self.QUERY_PARAM_FOR_APP_INSTANCE_ID in self._json_config else None
        self._currently_executing_job_id = str(self._json_config[
                                                   self.QUERY_PARAM_CURRENTLY_EXECUTING_JOB_ID]) if self.QUERY_PARAM_CURRENTLY_EXECUTING_JOB_ID in self._json_config else None
        self._pipeline_conf = self._json_config["cittaAgent"]["launcher"]["pipelineConf"] \
            if "cittaAgent" in self._json_config and "launcher" in self._json_config["cittaAgent"] and "pipelineConf" in \
               self._json_config["cittaAgent"]["launcher"] else None
        self._ml_code = self._pipeline_conf[
            self.ML_CODE_PROP] if self._pipeline_conf is not None and self.ML_CODE_PROP in self._pipeline_conf else None
        self._group_id = str(
            self._pipeline_conf["group"][
                self.GROUP_ID]) if self._pipeline_conf is not None and "group" in self._pipeline_conf and self.GROUP_ID in \
                                   self._pipeline_conf["group"] else None
        self._ep_id = str(
            self._pipeline_conf["execution_profile"][
                self.EP_ID]) if self._pipeline_conf is not None and "execution_profile" in self._pipeline_conf and self.EP_ID in \
                                self._pipeline_conf["execution_profile"] else None

    def get_object_from_app_config(self, key):
        return self._pipeline_conf[key]

    def does_app_config_contain_key(self, key):
        return key in self._pipeline_conf

    def get_object_from_base_config(self, key):
        return self._json_config[key]

    def does_base_config_contain_key(self, key):
        return key in self._json_config

    def get_current_execution_profile_id(self):
        return self._ep_id

    def get_ml_code(self):
        return self._ml_code

    def get_current_time_label(self):
        return self._time_label

    def get_current_bi_temporal_props(self):
        return self._bitemporal_props

    def get_currently_executing_job_id(self):
        return self._currently_executing_job_id

    def get_app_instance(self):
        return self._app_instance_id

    def get_current_group_id(self):
        return self._group_id

    def get_current_agi_id(self):
        return self._agiId

    def get_host_name(self):
        return self._host_name

    def get_session_code(self):
        return self._session_code

    def get_refresh_token(self):
        return self._token

    def get_current_app_instance_id(self):
        return self._app_instance_id



from thotnr_ml_client import MLModel
import requests


def test():
    url = 'https://zs-ae-dev.icops.dev.zsservices.com/datatypes/zpsa_265_1024_2179/app-api/graphql?dagContextId=8285&versionTagId=10990'

    headers = {
        'authority': 'zs-ae-dev.icops.dev.zsservices.com',
        'accept': 'application/json',
        'accept-language': 'en,ar;q=0.9',
        'authorization': 'Bearer eyJraWQiOiJ0RlZ4UndEU0R4WXZaeFUxNlV4WFwvZEE4QWhlbXM5aFdEdnBobUVPeWdwQT0iLCJhbGciOiJSUzI1NiJ9.eyJzdWIiOiI3YjFhMjUyZC1jNDlhLTQzNzItYTk0Ny1lYzY3NTkzZTk3ZWYiLCJpc3MiOiJodHRwczpcL1wvY29nbml0by1pZHAudXMtZWFzdC0xLmFtYXpvbmF3cy5jb21cL3VzLWVhc3QtMV9DWEJMRTBxVlYiLCJ2ZXJzaW9uIjoyLCJjbGllbnRfaWQiOiIyM2JhOXI2NDJxc2kwM2RocjMzZm5uNG9mMSIsIm9yaWdpbl9qdGkiOiI5OGFkMjYzOS1lOGIyLTQxNDctYmFhYi0yMTJkMmZkNzcyNDgiLCJldmVudF9pZCI6IjE5YTVhNDdiLTZkOWItNGNiYi04NjQyLWU2MjEyNzUwZTMzOSIsInRva2VuX3VzZSI6ImFjY2VzcyIsInNjb3BlIjoiYXdzLmNvZ25pdG8uc2lnbmluLnVzZXIuYWRtaW4gcGhvbmUgb3BlbmlkIGVtYWlsIiwiYXV0aF90aW1lIjoxNjk4ODk4MzAxLCJleHAiOjE2OTg5MDU1MjYsImlhdCI6MTY5ODkwMTkyNiwianRpIjoiYWRiZjM5NDctMzQzNC00MzBjLWIyY2MtNWU2ZjQ0Y2Q2NmFmIiwidXNlcm5hbWUiOiJTYW5rZXQifQ.D-m7mstT4U2eWHSFgYvcJNBHhOScj8dHRbis6d3YiWJwbWOkIX1aLQ1GWhZ6RfM2GRwyioSRRIVVgu26h50dSS-ujarfty5lOD-UxaCcB7PnXAJVq3ebMt0eoOreRcCjIWndLAp6nCu3GLrUnQ_Fs7IZlpactIGm1ledpc7Bsn8OVIam4EwOe0m8bAt4QMA0FP8eSNDOHGf_Slo8X-Z682DgdiryRvpW5aLfLnhctRg8fkn5RdbhYNpfcdLdL7-7bQsZwZupH8e1ay-kSKLK7TAbW8gu_EKrCokd4WEYJ-zO0u2a8HtGvsj0IjXYcIaMWxElqYT5MK7IUBbL_a_9_g',
        'bitemporalprops': '{"default":{"as_of_ts":"now","valid_ts":"now"}}',
        'content-type': 'application/json; charset=utf-8',
        'cookie': 'auth="Bearer eyJraWQiOiJ0RlZ4UndEU0R4WXZaeFUxNlV4WFwvZEE4QWhlbXM5aFdEdnBobUVPeWdwQT0iLCJhbGciOiJSUzI1NiJ9.eyJzdWIiOiI3YjFhMjU2ZC1jNDlhLTQzNzItYTk0Ny1e',
        'graphqloptype': 'query',
        'origin': 'https://zs-ae-dev.icops.dev.zsservices.com',
        'referer': 'https://zs-ae-dev.icops.dev.zsservices.com/apps/zpsa_265_1024_2179/instance/object/8487',
        'sec-ch-ua': '"Google Chrome";v="117", "Not;A=Brand";v="8", "Chromium";v="117"',
        'sec-ch-ua-mobile': '?0',
        'sec-ch-ua-platform': '"Linux"',
        'sec-fetch-dest': 'empty',
        'sec-fetch-mode': 'cors',
        'sec-fetch-site': 'same-origin',
        'uacacheid': '41809',
        'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/117.0.0.0 Safari/537.36',
        'userid': '2674'
    }

    data = {
        "query": 'query MyQuery {\n  MlModel1486_api(condition: null,\n  first: 11,\n  offset: 0,\n  orderBy: modified_on_desc,\n  ) {\n    edges {\n      node {\n        MlModel1486_id,is_deleted,created_by,modified_by,created_on,modified_on,mlCode,s3Path,isActive,groupId,modelMetadata\n      }\n      cursor\n    }\n  }\n}    \n'
    }

    response = requests.post(url, headers=headers, json=data)

    if response.status_code == 200:
        print(response.text)
    else:
        print(f"Request failed with status code: {response.status_code}")



if __name__ == '__main__':
    ml_model = MLModel()
    print(ml_model.get_current_active_model())
    # test()


